@@ -32,7 +32,9 @@ pub mod acl;
 pub mod actions;
 #[cfg(feature = "cache")]
 pub mod cache;
-#[cfg(feature = "events")]
+#[cfg(feature = "common-payloads")]
+pub mod common_payloads;
+#[cfg(any(feature = "events", feature = "common-payloads"))]
 pub mod events;
 #[cfg(feature = "ext")]
 pub mod ext;
