@@ -71,7 +71,6 @@ fn default_workers() -> u32 {
 
 /// Initial properties for services
 #[derive(Debug, Serialize, Deserialize)]
-#[serde(deny_unknown_fields)]
 pub struct Initial {
     #[serde(rename = "version")]
     config_version: u16,
@@ -187,6 +186,10 @@ impl Initial {
         self.core.log_level
     }
     #[inline]
+    pub fn core_active(&self) -> bool {
+        self.core.active
+    }
+    #[inline]
     pub fn eva_log_level_filter(&self) -> log::LevelFilter {
         match self.core.log_level {
             crate::LOG_LEVEL_TRACE => log::LevelFilter::Trace,
@@ -278,7 +281,6 @@ impl Initial {
 }
 
 #[derive(Debug, Serialize, Deserialize, Clone, Default)]
-#[serde(deny_unknown_fields)]
 pub struct Timeout {
     startup: Option<f64>,
     shutdown: Option<f64>,
@@ -309,23 +311,31 @@ impl Timeout {
 }
 
 #[derive(Debug, Serialize, Deserialize)]
-#[serde(deny_unknown_fields)]
 pub struct CoreInfo {
     build: u64,
     version: String,
     eapi_verion: u16,
     path: String,
     log_level: u8,
+    active: bool,
 }
 
 impl CoreInfo {
-    pub fn new(build: u64, version: &str, eapi_verion: u16, path: &str, log_level: u8) -> Self {
+    pub fn new(
+        build: u64,
+        version: &str,
+        eapi_verion: u16,
+        path: &str,
+        log_level: u8,
+        active: bool,
+    ) -> Self {
         Self {
             build,
             version: version.to_owned(),
             eapi_verion,
             path: path.to_owned(),
             log_level,
+            active,
         }
     }
 }
@@ -357,7 +367,6 @@ fn default_elbus_ping_interval() -> f64 {
 }
 
 #[derive(Debug, Clone, Deserialize, Serialize)]
-#[serde(deny_unknown_fields)]
 pub struct BusConfig {
     #[serde(rename = "type", default = "default_bus_type")]
     tp: String,
